Detective
---------


.. image:: https://img.shields.io/pypi/pyversions/detective.svg
   :target: https://www.python.org/
   :alt: Python version

.. image:: https://img.shields.io/pypi/v/detective.svg
   :target: https://pypi.python.org/pypi/detective/
   :alt: PyPi version

.. image:: https://img.shields.io/pypi/l/detective.svg
   :target: https://github.com/tijme/detective/blob/master/LICENSE.rst
   :alt: License: MIT


Detective helps you find information (at your favorite bug bounty program) that you are not supposed to see. It primarily focuses on information disclosure and sensitive data exposure vulnerabilities.

1. Specify the program's scope.
2. Run detective and wait.
3. Profit!


Table of contents
-----------------

-  `Installation <#installation>`__
-  `Documentation <#documentation>`__
-  `Issues <#issues>`__
-  `License <#license>`__

Installation
------------

First make sure you're on `Python 2.7/3.3 <https://www.python.org/>`__ or higher. Then run the command below to install Detective.

``$ pip install --upgrade detective``

Documentation
-------------

#ToDo

Issues
------

Issues or new features can be reported via the GitHub issue tracker. Please make sure your issue or feature has not yet been reported by anyone else before submitting a new one.

License
-------

Detective is open-sourced software licensed under the `MIT license <https://github.com/tijme/detective/blob/master/LICENSE.rst>`__.
